==> hypersnapsdk_flutter-1.2.1.tar.gz: android/src/main/java/co/hyperverge/hypersnapsdk/hypersnapsdk_flutter/FLHVNetworkHelper.java <==
package co.hyperverge.hypersnapsdk.hypersnapsdk_flutter;

import android.app.Activity;
import android.os.Build;
import android.util.Log;

import androidx.annotation.RequiresApi;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;

import org.json.JSONException;
import org.json.JSONObject;

import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;

import co.hyperverge.hypersnapsdk.listeners.APICompletionCallback;
import co.hyperverge.hypersnapsdk.network.HVNetworkHelper;
import co.hyperverge.hypersnapsdk.objects.HVError;
import co.hyperverge.hypersnapsdk.objects.HVResponse;
import co.hyperverge.hypersnapsdk.objects.HyperSnapParams;

public class FLHVNetworkHelper {
    private static final String TAG = FLHVNetworkHelper.class.getSimpleName();

    public static JSONObject convertMapToJson(Map<String, Object> map) throws JSONException {
        JSONObject object = new JSONObject();
        ObjectMapper objectMapper = new ObjectMapper();

        try {
            String json = objectMapper.writeValueAsString(map);
            object = new JSONObject(json);
        } catch (JsonProcessingException e) {
            Log.e(TAG, e.getMessage());
        }
        return object;
    }

    public static Map<String, Object> convertJsonToMap(JSONObject jsonObject) {
        ObjectMapper mapper = new ObjectMapper();
        String jsonString = jsonObject.toString();
        Map<String, Object> map = new HashMap<>();
        try {
            map = mapper.readValue(jsonString, new TypeReference<Map<String, Object>>() {
            });
        } catch (IOException e) {
            Log.e(TAG, e.getMessage());
        }
        return map;
    }

    @RequiresApi(api = Build.VERSION_CODES.KITKAT)
    public void makeOCRCall(Activity activity, String endpoint, String documentUri, Map<String, Object> parameters, Map<String, Object> headers, final APICompletionCallback resultCallback) {

        try {
            JSONObject params = new JSONObject();
            if (parameters != null) {
                params = convertMapToJson(parameters);
            }

            JSONObject headers2 = new JSONObject();
            if (headers != null) {
                headers2 = convertMapToJson(headers);
            }
            HVNetworkHelper.makeOCRCall(activity, endpoint, documentUri, params, headers2, resultCallback);
        } catch (Exception e) {
            Log.e(TAG, Objects.requireNonNull(e.getMessage()));
        }
    }

    @RequiresApi(api = Build.VERSION_CODES.KITKAT)
    public void makeFaceMatchCall(Activity activity, String endpoint, String faceUri, String documentUri, String faceMatchModeString, Map<String, Object> parameters, Map<String, Object> headers, final APICompletionCallback resultCallback) {
        try {
            JSONObject params = new JSONObject();
            if (parameters != null) {
                params = convertMapToJson(parameters);
            }

            JSONObject headers2 = new JSONObject();
            if (headers != null) {
                headers2 = convertMapToJson(headers);
            }

            HyperSnapParams.FaceMatchMode faceMatchMode = getFaceMatchMode(faceMatchModeString);

            HVNetworkHelper.makeFaceMatchCall(activity, endpoint, faceUri, documentUri, faceMatchMode, params, headers2, resultCallback);
        } catch (JSONException e) {
            Log.e(TAG, Objects.requireNonNull(e.getMessage()));
        }
    }

    private HyperSnapParams.FaceMatchMode getFaceMatchMode(String faceMatchMode) {
        switch (faceMatchMode) {
            case "FACE_FACE":
                return HyperSnapParams.FaceMatchMode.FACE_FACE;
            case "FACE_ID_FACE_STRING":
                return HyperSnapParams.FaceMatchMode.FACE_ID_FACE_STRING;
            default:
                return HyperSnapParams.FaceMatchMode.FACE_ID;
        }
    }

    @RequiresApi(api = Build.VERSION_CODES.KITKAT)
    public List<Map<String, Object>> getArrayListFromOnResultNetworkHelper(HVError error, HVResponse hvResponse) {

        ArrayList<Map<String, Object>> arrayList = new ArrayList<>();


        Map<String, Object> errorObj = new HashMap<>();
        Map<String, Object> resultsObj = new HashMap<>();
        try {
            if (error != null) {
                errorObj.put("errorCode", error.getErrorCode());
                errorObj.put("errorMessage", error.getErrorMessage());
            }
            if (hvResponse != null) {
                JSONObject result = hvResponse.getApiResult();
                JSONObject headers = hvResponse.getApiHeaders();

                String imageURI = hvResponse.getImageURI();
                String fullImageUri = hvResponse.getFullImageURI();
                String action = hvResponse.getAction();
                String retakeMessage = hvResponse.getRetakeMessage();


                if (result != null) {
                    try {
                        resultsObj.put("apiResult", result.toString());
                        resultsObj.put("imageUri", imageURI);
                        if (fullImageUri != null && !fullImageUri.isEmpty()) {
                            resultsObj.put("fullImageUri", fullImageUri);
                        }
                        if (retakeMessage != null && !retakeMessage.isEmpty()) {
                            resultsObj.put("retakeMessage", retakeMessage);
                        }
                        if (action != null && !action.isEmpty()) {
                            resultsObj.put("action", action);
                        }
                    } catch (Exception e) {
                        Log.e(TAG, Objects.requireNonNull(e.getMessage()));
                    }
                }
                if (headers != null) {
                    try {
                        resultsObj.put("apiHeaders", headers.toString());
                    } catch (Exception e) {
                        Log.e(TAG, Objects.requireNonNull(e.getMessage()));
                    }
                }


            }

        } catch (Exception e) {
            Log.e(TAG, e.getMessage());
        }
        arrayList.add(errorObj);
        arrayList.add(resultsObj);
        return arrayList;
    }
}

==> hypersnapsdk_flutter-4.10.0.tar.gz: android/src/main/java/co/hyperverge/hypersnapsdk/hypersnapsdk_flutter/FLHVNetworkHelper.java <==
package co.hyperverge.hypersnapsdk.hypersnapsdk_flutter;

import android.app.Activity;
import android.util.Log;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;

import co.hyperverge.hypersnapsdk.listeners.APICompletionCallback;
import co.hyperverge.hypersnapsdk.network.HVNetworkHelper;
import co.hyperverge.hypersnapsdk.objects.HVError;
import co.hyperverge.hypersnapsdk.objects.HVResponse;
import co.hyperverge.hypersnapsdk.objects.HyperSnapParams;

public class FLHVNetworkHelper {
    private static final String TAG = FLHVNetworkHelper.class.getSimpleName();

    public void makeOCRCall(Activity activity, String endpoint, String documentUri, Map<String, Object> parameters, Map<String, Object> headers, final APICompletionCallback resultCallback) {

        try {
            JSONObject params = new JSONObject();
            if (parameters != null) {
                params = FLHVUtils.convertMapToJson(parameters);
            }

            JSONObject headers2 = new JSONObject();
            if (headers != null) {
                headers2 = FLHVUtils.convertMapToJson(headers);
            }
            HVNetworkHelper.makeOCRCall(activity, endpoint, documentUri, params, headers2, resultCallback);
        } catch (Exception e) {
            Log.e(TAG, Objects.requireNonNull(e.getMessage()));
        }
    }

    public void makeFaceMatchCall(Activity activity, String endpoint, String faceUri, String documentUri, String faceMatchModeString, Map<String, Object> parameters, Map<String, Object> headers, final APICompletionCallback resultCallback) {
        try {
            JSONObject params = new JSONObject();
            if (parameters != null) {
                params = FLHVUtils.convertMapToJson(parameters);
            }

            JSONObject headers2 = new JSONObject();
            if (headers != null) {
                headers2 = FLHVUtils.convertMapToJson(headers);
            }

            HyperSnapParams.FaceMatchMode faceMatchMode = getFaceMatchMode(faceMatchModeString);

            HVNetworkHelper.makeFaceMatchCall(activity, endpoint, faceUri, documentUri, faceMatchMode, params, headers2, resultCallback);
        } catch (JSONException e) {
            Log.e(TAG, Objects.requireNonNull(e.getMessage()));
        }
    }

    private HyperSnapParams.FaceMatchMode getFaceMatchMode(String faceMatchMode) {
        switch (faceMatchMode) {
            case "FACE_FACE":
                return HyperSnapParams.FaceMatchMode.FACE_FACE;
            case "FACE_ID_FACE_STRING":
                return HyperSnapParams.FaceMatchMode.FACE_ID_FACE_STRING;
            default:
                return HyperSnapParams.FaceMatchMode.FACE_ID;
        }
    }
}
